@@ -12,8 +12,10 @@ import webbrowser
 
 try:
     from pter.qtui import run_qtui
-except ImportError:
+    qterr = None
+except ImportError as exc:
     run_qtui = None
+    qterr = exc
 
 from pytodotxt import TodoTxt, Task, version
 from pter.searcher import Searcher, get_relative_date
@@ -74,6 +76,8 @@ DEFAULT_CONFIG = {
             common.SETTING_COL_TRACKING: '',
         },
         common.SETTING_GROUP_GUICOLORS: {
+            'project': '#9c27b0',
+            'context': '#2e7d32',
         },
         common.SETTING_GROUP_KEYS: {
         },
@@ -1543,8 +1547,11 @@ def run():
         conf.read([conffile])
 
     if pathlib.Path(sys.argv[0]).name == 'qpter':
-        sucess = -1
-        if run_qtui is not None:
+        success = -1
+        if run_qtui is None:
+            print(tr("PyQt5 is not installed or could otherwise not be imported: {}").format(qterr),
+                  file=sys.stderr)
+        else:
             success = 0
             run_qtui(Configuration(conf), sources, args)
 
