@@ -6,6 +6,7 @@ import pathlib
 
 from pytodotxt import Task, TodoTxt
 
+import PyQt5
 from PyQt5 import QtWidgets, QtCore, QtGui
 from PyQt5.QtWidgets import QApplication, QMainWindow
 from PyQt5.QtCore import Qt
@@ -321,8 +322,8 @@ class TaskList(QtWidgets.QTreeView):
         self.config = config
         self.human_friendly_dates = set(config.list(common.SETTING_GROUP_GENERAL,
                                                     common.SETTING_HUMAN_DATES))
-        self.attr_highlight = parse_colors(config, common.SETTING_GROUP_GUICOLORS)
-        self.color = parse_colors(config, common.SETTING_GROUP_GUIHIGHLIGHT)
+        self.attr_highlight = parse_colors(config, common.SETTING_GROUP_GUIHIGHLIGHT)
+        self.color = parse_colors(config, common.SETTING_GROUP_GUICOLORS)
 
         self.setAllColumnsShowFocus(True)
         self.contextmenu = menu
@@ -476,11 +477,11 @@ class DockWithSettings(QtWidgets.QDockWidget):
         
         self.setFloating(self.settings.bool(self.group, SETTING_FLOATING, 'no'))
 
-        pos = [int(v) for v in self.settings.list(self.group, SETTING_POSITION, "")]
+        pos = [int(v) for v in self.settings.list(self.group, SETTING_POSITION, "") if v.isnumeric()]
         if len(pos) == 2:
             self.move(*pos)
 
-        size = [int(v) for v in self.settings.list(self.group, SETTING_SIZE, "")]
+        size = [int(v) for v in self.settings.list(self.group, SETTING_SIZE, "") if v.isnumeric()]
         if len(size) == 2:
             self.resize(*size)
 
